*pytools* is an open source library containing general machine learning and visualisation
utilities for reuse, including:

- Basic tools for API development, supporting documentation, deprecation, and run-time validation
- Support for simulating classification and regression data
- Utilities for constructing complex expressions and rendering them as indented strings
- Support for fitting objects to data, and testing whether an object is fitted
- Parallelization based on the joblib package
- A lean MVC framework for rendering basic visualizations in different styles, e.g., as *matplotlib* charts or as plain text

.. Begin-Badges

|pypi| |conda| |python_versions| |code_style| |made_with_sphinx_doc| |License_badge|

.. End-Badges

License
---------------------------

*pytools* is licensed under Apache 2.0 as described in the
`LICENSE <https://github.com/BCG-Gamma/pytools/blob/develop/LICENSE>`_ file.

.. |conda| image:: https://anaconda.org/bcg_gamma/gamma-pytools/badges/version.svg
    :target: https://anaconda.org/BCG_Gamma/gamma-pytools

.. |pypi| image:: https://badge.fury.io/py/gamma-pytools.svg
    :target: https://pypi.org/project/gamma-pytools/

.. |python_versions| image:: https://img.shields.io/badge/python-3.6|3.7|3.8-blue.svg
    :target: https://www.python.org/downloads/release/python-380/

.. |code_style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

.. |made_with_sphinx_doc| image:: https://img.shields.io/badge/Made%20with-Sphinx-1f425f.svg
    :target: https://bcg-gamma.github.io/pytools/index.html

.. |license_badge| image:: https://img.shields.io/badge/License-Apache%202.0-olivegreen.svg
    :target: https://opensource.org/licenses/Apache-2.0